import os
import sys
import logging
import argparse
from d2lbook.utils import *

__all__  = ['deploy']

def deploy(config):
    parser = argparse.ArgumentParser(description='deploy')
    parser.add_argument('commands', nargs='+', help=' ')
    args = parser.parse_args(sys.argv[2:])
    deployer = Deployer(config)
    commands = {
        'html' : deployer.deploy_html,
        'pdf' : deployer.deploy_pdf,
        'pkg' : deployer.deploy_pkg,
    }
    for cmd in args.commands:
        commands[cmd]()

class Deployer(object):
    def __init__(self, config):
        self.config = config

    def _check(self):
        assert self.config.deploy['s3_bucket'] is not '', 'empty target URL'

    def deploy_html(self):
        self._check()
        bash_fname = os.path.join(os.path.dirname(__file__), 'upload_doc_s3.sh')
        run_cmd(['bash', bash_fname, self.config.html_dir, self.config.deploy['s3_bucket']])

    def deploy_pdf(self):
        self._check()
        url = self.config.deploy['s3_bucket']
        if not url.endswith('/'):
            url += '/'
        logging.info('cp %s to %s', self.config.pdf_fname, url)
        run_cmd(['aws s3 cp', self.config.pdf_fname, url, "--acl 'public-read' --quite"])

    def deploy_pkg(self):
        self._check()
        url = self.config.deploy['s3_bucket']
        if not url.endswith('/'):
            url += '/'
        logging.info('cp %s to %s', self.config.pkg_fname, url)
        run_cmd(['aws s3 cp', self.config.pkg_fname, url, "--acl 'public-read' --quite"])



import configparser
import os
import logging

class Config():
    def __init__(self, config_fname):
        if not os.path.exists(config_fname):
            logging.fatal('Failed to find the config', config_fname)
            logging.fatal('You can use "d2lbook create ." to create a default config')
            exit(-1)
        config = configparser.ConfigParser()
        print(os.path.join(
            os.path.dirname(__file__), 'config_default.ini'))
        default_config_name = os.path.join(
            os.path.dirname(__file__), 'config_default.ini')
        config.read(default_config_name)
        config.read(config_fname)
        self.build = config['build']
        self.deploy = config['deploy']
        self.project = config['project']

        # a bunch of directories
        self.src_dir = self.build['source_dir']
        self.tgt_dir = self.build['output_dir']
        self.eval_dir = os.path.join(self.tgt_dir, 'eval')
        self.rst_dir = os.path.join(self.tgt_dir, 'rst')
        self.html_dir = os.path.join(self.tgt_dir, 'html')
        self.pdf_dir = os.path.join(self.tgt_dir, 'pdf')

        # some targets names
        self.pdf_fname = os.path.join(self.pdf_dir, self.project['name']+'.pdf')
        self.pkg_fname = os.path.join(self.tgt_dir, self.project['name']+'.zip')



import os
import glob

def rm_ext(filename):
    return os.path.splitext(filename)[0]

def find_files(pattern, root=None):
    fnames = []
    patterns = pattern.split(' ')
    for p in patterns:
        if len(p) == 0:
            continue
        if root is not None:
            p = os.path.join(root, p)
        if os.path.isdir(p):
            p += '**'
        for fn in glob.glob(p, recursive=True):
            if os.path.isfile(fn):
                fnames.append(fn)
    return fnames

def get_mtimes(fnames):
    if isinstance(fnames, str):
        return os.path.getmtime(fnames)
    return [os.path.getmtime(fn) for fn in fnames]

def get_updated_files(src_fnames, src_dir, tgt_dir, new_ext=None, deps_mtime=0):
    updated_fnames = []
    for src_fn in src_fnames:
        tgt_fn = os.path.join(tgt_dir, os.path.relpath(src_fn, src_dir))
        if new_ext is not None:
            tgt_fn = rm_ext(tgt_fn) + '.' + new_ext
        if (not os.path.exists(tgt_fn) # new
            or get_mtimes(src_fn) > get_mtimes(tgt_fn) # target is old
            or get_mtimes(tgt_fn) < deps_mtime): # deps is updated
            updated_fnames.append((src_fn, tgt_fn))
    return updated_fnames

def mkdir(dirname):
    os.makedirs(dirname, exist_ok=True)

def run_cmd(cmd):
    if isinstance(cmd, str):
        cmd = [cmd]
    os.system(' '.join(cmd))



from setuptools import setup, find_packages
from d2lbook import __version__

requirements = [
    'jupyter',
    'sphinx>=1.7',
    'recommonmark',
    'sphinxcontrib-bibtex',
    'mu-notedown',
    'mxtheme>=0.3.6',
    'sphinxcontrib-svg2pdfconverter',
    'awscli',
]

setup(
    name='d2lbook',
    version=__version__,
    install_requires=requirements,
    python_requires='>=3.5',
    author='D2L Developers',
    author_email='d2l.devs@google.com',
    url='https://book.d2l.ai',
    description="Create an online book with Jupyter Notebooks and Sphinx",
    license='Apache-2.0',
    packages=find_packages(),
    include_package_data=True,
    package_data={'d2lbook':['config_default.ini', 'upload_doc_s3.sh']},
    entry_points={
        'console_scripts': [
            'd2lbook = d2lbook.main:main',
        ]
    },
)
